package com.qianhe.bzsc.service;

import java.util.List;
import com.qianhe.bzsc.domain.BzscCyglqglscMbcb;

/**
 * 标准手册-采油管理区管理手册-模板从Service接口
 * 
 * @author qianhe
 * @date 2024-11-11
 */
public interface IBzscCyglqglscMbcbService 
{
    /**
     * 查询标准手册-采油管理区管理手册-模板从
     * 
     * @param ID 标准手册-采油管理区管理手册-模板从主键
     * @return 标准手册-采油管理区管理手册-模板从
     */
    public BzscCyglqglscMbcb selectBzscCyglqglscMbcbByID(Long ID);

    /**
     * 查询标准手册-采油管理区管理手册-模板从列表
     * 
     * @param bzscCyglqglscMbcb 标准手册-采油管理区管理手册-模板从
     * @return 标准手册-采油管理区管理手册-模板从集合
     */
    public List<BzscCyglqglscMbcb> selectBzscCyglqglscMbcbList(BzscCyglqglscMbcb bzscCyglqglscMbcb);

    /**
     * 新增标准手册-采油管理区管理手册-模板从
     * 
     * @param bzscCyglqglscMbcb 标准手册-采油管理区管理手册-模板从
     * @return 结果
     */
    public int insertBzscCyglqglscMbcb(BzscCyglqglscMbcb bzscCyglqglscMbcb);

    /**
     * 修改标准手册-采油管理区管理手册-模板从
     * 
     * @param bzscCyglqglscMbcb 标准手册-采油管理区管理手册-模板从
     * @return 结果
     */
    public int updateBzscCyglqglscMbcb(BzscCyglqglscMbcb bzscCyglqglscMbcb);

    /**
     * 批量删除标准手册-采油管理区管理手册-模板从
     * 
     * @param IDs 需要删除的标准手册-采油管理区管理手册-模板从主键集合
     * @return 结果
     */
    public int deleteBzscCyglqglscMbcbByIDs(Long[] IDs);

    /**
     * 删除标准手册-采油管理区管理手册-模板从信息
     * 
     * @param ID 标准手册-采油管理区管理手册-模板从主键
     * @return 结果
     */
    public int deleteBzscCyglqglscMbcbByID(Long ID);

    public List<BzscCyglqglscMbcb> selectBzscCyglqglscMbcbList_ByZbid(Long zbId);

    public boolean hasChildByID(Long menuId);
}
